@@ -1,3 +1,5 @@
+import time
+
 logins = ["api", "tikot", "developer", "dev", "tikotshop"]
 passwords = ["pass", "p", "api", "tikotshop", "developer", "dev", "tikot"]
 services = ["tikot shop", "developer console"]
@@ -58,9 +60,6 @@ def panel_tikotshop(login2, password2):
 				print("Aborted!")
 				print("My ideas and your: tikotapi.helptoupgrade()")
 
-def helptoupgrade():
-	print("Send idea for upgrades to email: tikotstudio@yandex.ru")
-	print("My ideas: 1. Add more statistic game")
 
 def tutorial():
 	print("Welcome to tutorial in TIKOT API 1.0.2! I'm learn your using this API!")
@@ -90,4 +89,31 @@ def tutorial():
 			print("what is written in the caps then it will come in handy for us")
 
 	elif tutorialnext1 not in nexts:
-		print("Error! Write: next or Next")
\ No newline at end of file
+		print("Error! Write: next or Next")
+
+def panel_tikotworks(login4, password4):
+	if login4 not in logins:
+		print("Invalid login!")
+	elif password4 not in passwords:
+		print("Invalid password!")
+	else:
+		print("Loading...")
+		time.sleep(10)
+		print("Wait 1 minute plase!")
+		time.sleep(60)
+		print("Input name game:")
+		newgame = input("")
+		print("Adding...")
+		time.sleep(5)
+		print("For adding game in db send message in emain\ntikotstudio@yandex.ru")
+
+		print("Name new game: " + newgame)
+		yn2 = input("Yes/No? ")
+
+		if yn2 == "Yes":
+			print("Ok!")
+		if yn2 == "No":
+			print("Plase retry now!")
+
+def help():
+	print("tikotapi.connect() (this old)\ntikotapi.test(\"login\", \"password\")\ntikotapi.panel_tikotshop(\"login\", \"password\")\ntikotapi.panel_tikotworks(\"login\", \"password\")")
\ No newline at end of file
